import boto3
import json


def get_values(secret_arn: str):
    client = boto3.client('secretsmanager')
    response = client.get_secret_value(
        SecretId=secret_arn
    )
    return json.loads(response['SecretString'])



import click
import tomlkit
from ._secrets import get_values
from ._templating import render


@click.command()
@click.option('--template', default=None, help='Template file to use')
@click.option('--target', default=None, help='Target config file')
@click.option('--secret-arn', default=None, help='ARN of the AWS Secrets Manager secret to bind')
@click.option('--config', default='.sprinklesrc', help='sprinkles TOML config file')
def generate_config(template, target, secret_arn, config):
    if template is None:
        with open(config, 'r') as config_file:
            sprinkles_config = tomlkit.loads(config_file.read())
            _secret_arn = secret_arn or sprinkles_config['secret']['arn']
            values = get_values(_secret_arn)
            for section, files in sprinkles_config['files'].items():
                template_path = files['template']
                target_path = files['target']
                click.echo(
                    "Processing [{section}]: {template} -> {target}".format(
                        section=section,
                        template=template_path,
                        target=target_path
                    )
                )
                render(template_path, values, target_path)

    elif secret_arn is not None and template is not None:
        values = get_values(secret_arn)
        render(template, values, target)


if __name__ == '__main__':
    generate_config()



from click import echo
from jinja2 import Template


def merge(template_string: str, values: dict):
    template = Template(template_string)
    return template.render(values)


def render(template, values, target=None):
    with open(template, 'r') as template_file:
        template_string = template_file.read()

    output = merge(template_string, values)
    
    if target is not None:
        with open(target, 'w') as target_file:
            target_file.write(output)
    else:
        echo(output)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sprinkles']

package_data = \
{'': ['*']}

install_requires = \
['Jinja2', 'boto3', 'click', 'tomlkit']

entry_points = \
{'console_scripts': ['sprinkles = sprinkles.commands:generate_config']}

setup_kwargs = {
    'name': 'sprinkles-config',
    'version': '0.1.4',
    'description': 'Generate config files from AWS Secrets',
    'long_description': '[![PyPI version](https://badge.fury.io/py/sprinkles-config.svg)](https://badge.fury.io/py/sprinkles-config)\n\n# sprinkles\n\nSprinkles makes it easy to share configuration files between local dev\nenvironments without leaking private information. No more passwords in Slack\nPMs, no more API keys in VCS.\n\n# Installation\n\n```shell script\npip install sprinkles-config\n```\n\nPlease note that sprinkles has only been tested for Python versions >= 3.6.\n\n# Usage\n\nSprinkles reads secrets from AWS secrets manager, and binds them to a template\nyou provide. The templating is based on Jinja2¹, making it flexible enough to\nwork with any text-based configuration format you may be using. Anything from\n.env files, to Java properties, to yaml.\n\nIt has a simple param based CLI API, but can also be executed against a config\nfile to encourage reuse. The config format is TOML-based².\n\nNOTE: Sprinkles will use the AWS profile/credentials configured in the calling shell\ncontext, using the standard environment variables³.\n\n## CLI\n\n1. Output config to stdout\n\n```properties\nthird.party.api.endpoint=https://example.com/api/v1\nthird.party.api.key={{THIRD_PARTY_API_KEY}}\n```\n\n```\nsprinkles --template application.properties.j2 --secret-arn arn:aws:secretsmanager:<region>:<account-id-number>:secret:<secret-name>\n```\n\n2. Output to file\n\n```\nsprinkles --template application.properties.j2 --secret-arn arn:aws:secretsmanager:<region>:<account-id-number>:secret:<secret-name> --output application.properties\n```\n\n## Config file option\n\nSprinkles also makes it possible to have a set of defaults (tracked in VCS).\nAdd a .sprinklesrc file in your project root. Simply run `sprinkles` in the\nproject root to initialize the config.\n\n\n.sprinklesrc\n```toml\n[secret]\narn = "arn:aws:secretsmanager:<region>:<account-id-number>:secret:<secret-name>"\n\n[files]\n  [files.docker-env]\n    template = "sprinkles-templates/.env.sprinkles"\n    target = ".env"\n  [files.application-properties]\n    template = "sprinkles-templates/application.properties.sprinkles"\n    target = "src/main/com/example/resources/application-dev.properties"\n```\n\n# References\n\n1. Jinja2: https://jinja.palletsprojects.com/en/2.11.x/\n2. TOML: https://github.com/toml-lang/toml\n3. AWS Configuration: https://docs.aws.amazon.com/cli/latest/userguide/cli-configure-files.html\n',
    'author': 'Okal Otieno',
    'author_email': 'okal@justokal.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/okal/sprinkles',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
